@@ -33,6 +33,24 @@ void patchgdImageFill (gdImagePtr im, int x, int y, int color)
 }
 
 
+#define DASHPIXELS 8
+
+void myDashedLine(gdImagePtr im, int x1, int y1, int x2, int y2, int color);
+void myDashedLine(gdImagePtr im, int x1, int y1, int x2, int y2, int color){
+  /**
+   * emulates gdImageDashedLine with gdImageSetStyle and gdImageLine
+   * GK: As gdImageDashedLine is slightly broken in latest libgd libraries,
+   * GK: I implemented an emulation named "myDashedLine"
+   **/
+
+  int styleDashed[DASHPIXELS],i;
+  for (i=0; i< DASHPIXELS/2; i++) styleDashed[i]=color;
+  for (; i< DASHPIXELS; i++) styleDashed[i]=gdTransparent;
+  gdImageSetStyle(im, styleDashed, DASHPIXELS);
+  gdImageLine(im, x1, y1, x2, y2, gdStyled);
+}
+
+
 /* File opening: with security */
 FILE *open4read(char *n)
 {
@@ -178,7 +196,7 @@ void _obj_arrow(objparm *pm, int twoside)
       gdImageFilledPolygon(image, ii,3,pm->color[0]);
     }
     stem: if(pm->fill)
-      gdImageDashedLine(image,pm->p[0],pm->p[1],xx,yy,pm->color[0]);
+      myDashedLine(image,pm->p[0],pm->p[1],xx,yy,pm->color[0]);
     else
       gdImageLine(image,pm->p[0],pm->p[1],xx,yy,pm->color[0]);
     if(vimg_enable) vimg_line(scale_buf[0],scale_buf[1],scale_buf[2],scale_buf[3]);
@@ -201,7 +219,7 @@ void obj_hline(objparm *pm)
 {
     scale(pm->pd,pm->p,1);
     if(pm->fill)
-      gdImageDashedLine(image,0,pm->p[1],sizex,pm->p[1],pm->color[0]);
+      myDashedLine(image,0,pm->p[1],sizex,pm->p[1],pm->color[0]);
     else
       gdImageLine(image,0,pm->p[1],sizex,pm->p[1],pm->color[0]);
 }
@@ -211,7 +229,7 @@ void obj_vline(objparm *pm)
 {
     scale(pm->pd,pm->p,1);
     if(pm->fill)
-      gdImageDashedLine(image,pm->p[0],0,pm->p[0],sizey,pm->color[0]);
+      myDashedLine(image,pm->p[0],0,pm->p[0],sizey,pm->color[0]);
     else
       gdImageLine(image,pm->p[0],0,pm->p[0],sizey,pm->color[0]);
 }
@@ -220,8 +238,7 @@ void obj_vline(objparm *pm)
 void obj_dline(objparm *pm)
 {
     scale(pm->pd,pm->p,2);
-    gdImageDashedLine(image,pm->p[0],pm->p[1],pm->p[2],pm->p[3],
-                  pm->color[0]);
+    myDashedLine(image,pm->p[0],pm->p[1],pm->p[2],pm->p[3], pm->color[0]);
 }
 
 /* parallel lines.
@@ -349,7 +366,7 @@ void obj_dlines(objparm *pm)
     n=(pm->pcnt)/2;
     scale(pm->pd,pm->p,n);
     for(i=2;i<2*n;i+=2)
-      gdImageDashedLine(image,pm->p[i-2],pm->p[i-1],pm->p[i],pm->p[i+1],pm->color[0]);
+      myDashedLine(image,pm->p[i-2],pm->p[i-1],pm->p[i],pm->p[i+1],pm->color[0]);
     if(vimg_enable) vimg_polyline(scale_buf,n,0);
 }
 
@@ -370,7 +387,8 @@ void obj_lattice(objparm *pm)
     int n1,n2,i1,i2,xi1,yi1,xi2,yi2;
     double xv1,xv2,yv1,yv2;
     n1=pm->pd[6];n2=pm->pd[7]; if(n1<0 || n2<0) return;
-    if(n1>256) n1=256; if(n2>256) n2=256;
+    if(n1>256) n1=256;
+    if(n2>256) n2=256;
     scale(pm->pd,pm->p,1);
     scale2(pm->pd[2],pm->pd[3],&xv1,&yv1);
     scale2(pm->pd[4],pm->pd[5],&xv2,&yv2);
@@ -783,7 +801,8 @@ void obj_plotjump(objparm *pm)
 {
     int dd;
     dd=pm->pd[0];
-    if(dd<3) dd=3; if(dd>MAX_SIZE) dd=MAX_SIZE;
+    if(dd<3) dd=3;
+    if(dd>MAX_SIZE) dd=MAX_SIZE;
     plotjump=dd;
 }
 
@@ -858,7 +877,8 @@ void obj_levelstep(objparm *pm)
 {
     int dd;
     dd=pm->pd[0];
-    if(dd<1) return; if(dd>16) dd=16;
+    if(dd<1) return;
+    if(dd>16) dd=16;
     lstep=dd;
 }
 
@@ -1256,7 +1276,9 @@ int parse_parms(char *p,objparm *pm,struct objtab *o)
 
     c=o->color_pos;c1=c2=0;
     pm->color[0]=pm->color[1]=0;
-    if(c>0) c1=c; if(c<0) c2=-c; c=c1+c2;
+    if(c>0) c1=c;
+    if(c<0) c2=-c;
+    c=c1+c2;
     t=itemnum(p);if(t<o->required_parms+3*c) return -1;
     if(c1>0 && t>o->required_parms+3*c) t=o->required_parms+3*c;
     pm->pcnt=t-3*c;
