@@ -127,7 +127,8 @@ char *find_tag_end(char *p)
         if(pp==NULL) return p+strlen(p); else continue;
     }
     }
-    if(*pp=='>') pp++; return pp;
+    if(*pp=='>') pp++;
+    return pp;
 }
 
 char *find_tag(char *p, char *tag)
@@ -595,10 +596,11 @@ void onemodule(const char *name, int serial, int lind)
     p1=find_word_start(p2)) {
       p2=find_word_end(p1);
       if(p2!=NULL) *p2++=0; else p2=p1+strlen(p1);
-      if(!isalpha(*p1) ||
+      if(strncmp(p1, "Lang" , p2-p1) &&
+       (!isalpha(*p1) ||
        (!isdigit(*(p1+1)) && *(p1+1)!=0) ||
-       (*(p1+1)!=0 && *(p1+2)!=0))
-      continue;
+       (*(p1+1)!=0 && *(p1+2)!=0)))
+         continue;
       *p1=tolower(*p1);
       ovlstrcpy(lbuf+strlen("level"),p1);
       appenditem(lbuf,lind,serial,2,module_language);
@@ -732,9 +734,10 @@ void onesheet(int serial, int lind)
     if(strlen(p1)<=0) continue;
     sappenditem(p1,lind,serial,4);
     }
-    snprintf(buf,sizeof(buf),"%s, %s, %s, %s",
-         sindbuf[s_description],sindbuf[s_keywords],
-         sindbuf[s_domain],sindbuf[s_information]);
+    unknown_type=unk_leave;
+    snprintf(buf,sizeof(buf),"%s, %s",
+         sindbuf[s_keywords],
+         sindbuf[s_domain]);
     translate(buf);
     for(p1=find_word_start(buf); *p1;
     p1=find_word_start(p2)) {
