@@ -360,7 +360,7 @@ void exec_read(char *p)
       if((untrust&255)!=0 &&
         (m_file.name[0]=='/' || strncmp(m_file.name,"wimshome/",9)==0))
         module_error("Illegal_file_access");
-        untrust|=0x200;
+      untrust|=0x200;
     }
     if((untrust&0x202)!=0) {
       pp=getvar("wims_trustfile");
@@ -371,6 +371,13 @@ void exec_read(char *p)
     if(outputing) phtml_put(p,cache); else var_proc(p,cache);
     readnest--; untrust=t;
     memmove(&m_file,&save,sizeof(WORKING_FILE));
+    if (trace_file)
+    {
+      int i;
+      putc('\n',trace_file);
+      for(i=1; i<=2*trace_indent-2; i++) putc(' ',trace_file);
+      fprintf(trace_file,"%s:",m_file.filepath); fflush(trace_file);
+    }
     setvar("wims_read_parm",parmsave);
 }
 
@@ -505,7 +512,8 @@ void exec_tail(char *p)
     if(!outputing || tail_executed) {
       *p=0; return;
     }
-    if(!ismhelp) exec_homeref(p); *p=0;
+    if(!ismhelp) exec_homeref(p);
+    *p=0;
     _output_("</body></html>");
     tail_executed=1;
 }
@@ -517,19 +525,24 @@ void exec_formend(char *p)
 
 void determine_font(char *l);
 
+/* see changelog wims_mathml for history */
 void _headmathjax ( char *p)
 {
-   _output_("\n<script type=\"text/javascript\">/*<![CDATA[*/if(\
-navigator.userAgent.toLowerCase().indexOf(\"firefox\") == -1 &&\
-navigator.userAgent.toLowerCase().indexOf(\"opera\") == -1 &&\
-(navigator.userAgent.toLowerCase().indexOf(\"safari\") == -1 ||\
- navigator.userAgent.toLowerCase().indexOf(\"chrome\") > 0 ||\
- navigator.userAgent.toLowerCase().indexOf(\"android\") > 0)\
-){var script = document.createElement(\"script\");\
-script.type = \"text/javascript\";\
-script.src  = \"scripts/js/mathjax/MathJax.js?config=MML_HTMLorMML-full.js\";\
-document.body.appendChild(script);\
-}/*]]>*/</script>\n");
+   _output_("\n<script type=\"text/javascript\">/*<![CDATA[*/\
+function wims_mathml_zoom(id){\
+var math = document.getElementById(id);\
+if(math.getAttribute(\"mathsize\") == \"100%\"){\
+  math.setAttribute(\"mathsize\",\"200%\");}else{\
+  math.setAttribute(\"mathsize\",\"100%\");};\
+};\
+var ua = navigator.userAgent.toLowerCase();\
+var gecko = ua.indexOf(\"gecko\") > -1 && ua.indexOf(\"khtml\") === -1 && ua.indexOf(\"trident\") === -1;\
+if(! gecko ){\
+ var script = document.createElement(\"script\");\
+ script.type = \"text/javascript\";\
+ script.src  = \"scripts/js/mathjax/MathJax.js?config=MML_HTMLorMML-full.js\";\
+ document.body.appendChild(script);\
+};/*]]>*/</script>\n");
 }
 
 /* standardized header */
@@ -599,14 +612,13 @@ void _header(char *p, int option)
        hbuf,s2,ol,wsbuf2,bo);*/
        /*http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd*/
      if(ol[0]) {
-        output("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1 plus MathML 2.0//EN\" \"http://www.w3.org/Math/DTD/mathml2/xhtml-math11-f.dtd\">\
-        \n<html xml:lang=\"%s\"\
-        xmlns=\"http://www.w3.org/1999/xhtml\" xmlns:mathml=\"http://www.w3.org/1998/Math/MathML\"><head>%s\n\
-     </head>\n<body %s %s\"%s\" %s>", lang,hbuf,s2,ol,wsbuf2,bo);}
+        output("<!DOCTYPE html>\
+        \n<html><head>%s\n\
+        </head>\n<body %s %s\"%s\" %s>", hbuf,s2,ol,wsbuf2,bo);}
      else {
-       output("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1 plus MathML 2.0//EN\" \"http://www.w3.org/Math/DTD/mathml2/xhtml-math11-f.dtd\">\
-        \n<html xml:lang=\"%s\" xmlns=\"http://www.w3.org/1999/xhtml\" xmlns:mathml=\"http://www.w3.org/1998/Math/MathML\"><head>%s\n\
-        </head>\n<body %s %s%s %s>", lang,hbuf,s2,ol,wsbuf2,bo);
+       output("<!DOCTYPE html>\
+        \n<html><head>%s\n\
+        </head>\n<body %s %s%s %s>",hbuf,s2,ol,wsbuf2,bo);
     }
     _headmathjax(p);
     exec_headmenu(p);
@@ -717,7 +729,7 @@ void exec_restart(char *p)
       else goto usual;
     }
     printf("Location: %s\r\n\r\n\
-<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\
+<!DOCTYPE html>\
 <html><body><a href=\"%s\">%s</a></body></html>",buf2,buf2,buf2);
     close_working_file(&m_file,0); write_logs();
     snprintf(buf,sizeof(buf),"%ld",(long)nowtime);
@@ -735,7 +747,8 @@ void href_find_target(char *p)
       if(strncasecmp(pp,"target=wims_",strlen("target=wims_"))!=0) continue;
       memmove(buf1,pp,pe-pp); buf1[pe-pp]=0; substit(buf1);
       if(strncasecmp(buf1,"target=wims_mhelp",strlen("target=wims_mhelp"))==0) {
-        if(*pe!=0) *pe++=0; ovlstrcpy(href_target,"wims_help");
+        if(*pe!=0) *pe++=0;
+        ovlstrcpy(href_target,"wims_help");
         ref_mhelp=1;
       }
       else {
@@ -1145,7 +1158,8 @@ void _exec_ins(char *p, char *script_name,char *format)
     tag=getvar("ins_tag");  al=getvar("ins_align");
     if(at==NULL) at="";
     if(tag==NULL) tag="";
-    if(al==NULL) al="";al=find_word_start(al);
+    if(al==NULL) al="";
+    al=find_word_start(al);
     if(*al!=0) snprintf(buf2,sizeof(buf2),"vertical-align:%s",al); else buf2[0]=0;
     if(strcasecmp(al,"middle")==0) middle=1; else middle=0;
     tag2=""; vspace=0;
@@ -1157,7 +1171,8 @@ void _exec_ins(char *p, char *script_name,char *format)
     }
     if(b==NULL || *b==0) border=0;
     else border=atoi(b);
-    if(border<0) border=0; if(border>100) border=100;
+    if(border<0) border=0;
+    if(border>100) border=100;
     if(middle) {
       snprintf(outbuf+strlen(outbuf),
          sizeof(outbuf)-strlen(outbuf),"%s",mathalign_sup1);
@@ -1338,7 +1353,8 @@ void prepare_insplot_parm(char *p)
 /* frames of animation */
     pp=getvar("ins_anim_frames");
     if(pp!=NULL) i=evalue(pp); else i=1;
-    if(i>=ANIM_LIMIT) i=ANIM_LIMIT-1; if(i<1) i=1;
+    if(i>=ANIM_LIMIT) i=ANIM_LIMIT-1;
+    if(i<1) i=1;
     if(strstr(setbuf,"step")==NULL && strstr(p,"step")==NULL
        && varchr(setbuf,"s")==NULL && varchr(p,"s")==NULL && !multanim) i=1;
     setenv("ins_anim_frames",int2str(i),1);
@@ -1348,7 +1364,8 @@ void prepare_insplot_parm(char *p)
 /* delay of animation */
     pp=getvar("ins_anim_delay");
     if(pp!=NULL) d=evalue(pp); else d=0;
-    if(d>=10) d=10; if(d<0) d=0;
+    if(d>=10) d=10;
+    if(d<0) d=0;
     setenv("ins_anim_delay",int2str(d*100),1);
 }
 
@@ -1398,7 +1415,8 @@ void exec_insdraw(char *p)
 /* frames of animation */
     pp=getvar("ins_anim_frames");
     if(pp!=NULL) i=evalue(pp); else i=1;
-    if(i>=ANIM_LIMIT) i=ANIM_LIMIT-1; if(i<1) i=1;
+    if(i>=ANIM_LIMIT) i=ANIM_LIMIT-1;
+    if(i<1) i=1;
     if(i>1 && varchr(p,"s")==NULL && varchr(p,"animstep")==NULL
        && varchr(p,"step")==NULL) i=1;
     setenv("ins_anim_frames",int2str(i),1);
@@ -1408,7 +1426,8 @@ void exec_insdraw(char *p)
 /* delay of animation */
     pp=getvar("ins_anim_delay");
     if(pp!=NULL) d=evalue(pp); else d=0;
-    if(d>=10) d=10; if(d<0) d=0;
+    if(d>=10) d=10;
+    if(d<0) d=0;
     setenv("ins_anim_delay",int2str(d*100),1);
     pp=getvar("insdraw_filebase");
     if(pp!=NULL && strstr(pp,parent_dir_string)!=NULL)
@@ -1967,9 +1986,11 @@ static void _skip_contents(int isif)
       if(i<0) continue;
       switch(exec_routine[i].tag & 0xffff) {
         case EXEC_WHILE:
-          if(!isif) loop++; break;
+          if(!isif) loop++;
+          break;
         case EXEC_IF:
-          if(isif) loop++; break;
+          if(isif) loop++;
+          break;
         case EXEC_ELSE: {
           if(!isif) break;
           if(loop<=0) return; else break;
