@@ -293,7 +293,7 @@ int check_session(void)
      if(n>=varget_no) continue;
      m=pl+strlen(ro_name[i]);
      if(tbuf[m]!='=' || tbuf[m+1]==0) continue;
-     if(i==ro_module && cmd_type!=cmd_new && cmd_type!=cmd_intro) {
+     if(i==ro_module && cmd_type!=cmd_new && cmd_type!=cmd_intro && cmd_type!=cmd_help) {
          char *pp;
          pp=getvar(ro_name[i]);
          if(pp!=NULL && *pp!=0 && strcmp(pp,tbuf+m+1)!=0) badmod=1;
@@ -673,9 +673,10 @@ int var_def_name(char *n, int v)
      *q++=0; r=find_matching(q,']');
      if(r==NULL) goto illegal;
      *r=0; int i;
-      for(i=0;i<special_name_no && strcmp(q, special_name[i].name)!=0; i++);
-      if(i<special_name_no) j=special_name[i].value; else j=atoi(q);
-      if(j<1) j=1; if(j>MAX_VAR_NUM) j=MAX_VAR_NUM;
+     for(i=0;i<special_name_no && strcmp(q, special_name[i].name)!=0; i++);
+     if(i<special_name_no) j=special_name[i].value; else j=atoi(q);
+     if(j<1) j=1;
+     if(j>MAX_VAR_NUM) j=MAX_VAR_NUM;
      var_def[v].beg=1; var_def[v].end=j;
      return j;
     }
@@ -822,6 +823,21 @@ void set_vars_from_session(void)
     close_working_file(&m_file,0);
 }
 
+void start_tracefile(void)
+{
+  int i;
+  putc('\n',trace_file);
+  for(i=1; i<=2*trace_indent; i++) putc(' ',trace_file);
+  fprintf(trace_file,"%s:",m_file.filepath);
+  fflush(trace_file);
+  trace_indent++;
+}
+
+void stop_tracefile(void)
+{
+  trace_indent--;
+}
+
 /* Initialize environment variables according to module's
  * variable init or calculation file.
  * init is only used when cmd=new or renew.
@@ -833,7 +849,10 @@ void var_proc(char *fname,int cache)
 
     if(fname!=NULL && read_module_file(fname)) return;
     if(untrust&6) get_var_privileges();
+    if (trace_file) start_tracefile();
     while(m_file.linepointer<m_file.linecnt) {
+     if (trace_file) {fprintf(trace_file," %d",m_file.linepointer+1);
+       fflush(trace_file); }
      t=m_file.lines[m_file.linepointer].isstart;
      if((t&~2)!=1 || m_file.lines[m_file.linepointer].llen==0) {
          m_file.linepointer++; continue;
@@ -843,6 +862,7 @@ void var_proc(char *fname,int cache)
      if((t&2)!=0) exec_main(p+1);
      else exec_set(p);
     }
+    if (trace_file) stop_tracefile();
     close_working_file(&m_file,cache);
 }
 
@@ -853,7 +873,8 @@ void var_deposit(char *p)
     int l,fd;
     if(!trusted_module()) return;
     if(deplen>0) l=deplen; else {
-     while(isspace(*p)) p++; l=strlen(p);
+     while(isspace(*p)) p++;
+     l=strlen(p);
     }
     if(l<=0) return;
     if(l>MAX_DEPOSITLEN) l=MAX_DEPOSITLEN; /* silent truncation, should not occur */
@@ -1123,13 +1144,17 @@ void phtml_put(char *fname,int cache)
      /* File not found; we give empty output, but no error message. */
     if(fname!=NULL && read_module_file(fname)!=0) return;
     if(untrust&6) get_var_privileges();
+    if (trace_file) start_tracefile();
     while(m_file.linepointer<m_file.linecnt) {
+	 if (trace_file) { fprintf(trace_file," %d",m_file.linepointer+1);
+	                   fflush(trace_file); }
      t=m_file.lines[m_file.linepointer].isstart;
      if((t&~18)!=1) {m_file.linepointer++; continue;}
      wgetline(tbuf,MAX_LINELEN,&m_file); substnest=0;
      if((t&2)!=0) {exec_main(tbuf+1); continue;}
      substit(tbuf); output0(tbuf); _output_("\n");
     }
+    if (trace_file) stop_tracefile();
     close_working_file(&m_file,cache);
 }
 
@@ -1149,7 +1174,7 @@ void phtml_put_base(char *fname,int cache)
 /* Read main.phtml, process it, and write to stdout. */
 void main_phtml_put(char *mname)
 {
-    char *p, buf[1024], txbuf[256], dirnbuf[256], bgbuf[256], spfbuf[256];
+    char *p, buf[1024], txbuf[256], dirnbuf[256], bgbuf[256], spfbuf[256], ebuf[256];
     char *bcolor, *refcolor, *bg, *tx, *dirn, *vlink, *link, *spf ;
     define_html_header(); readnest=0;
     nph_header(200);
@@ -1158,6 +1183,23 @@ void main_phtml_put(char *mname)
     p=getvar("wims_expire");
     if(p!=NULL) p=strstr(p,"no-cache");
     if(p!=NULL) _output_("Cache-Control: no-cache\r\nPragma: no-cache\r\n");
+/* expiration date */
+    if(mode==mode_default) {
+      if(!robot_access && (cmd_type!=cmd_intro || p!=NULL)) {
+        char *expir="Sat, 26 Jul 1990 05:00:00 GMT";
+        snprintf(ebuf,sizeof(ebuf),"%s",expir);
+      }
+      else {
+/* expiration in 10 days for robot access or intro page. */
+        time_t t=nowtime+(long) 10*24*3600;
+        { struct tm *tt = localtime(&t);
+          strftime(ebuf,sizeof(ebuf),"%a, %d %b %Y %T GMT", tt);
+        }
+      }
+      strip_trailing_spaces(ebuf);
+      output("Expires:%s\r\n",ebuf);
+    }
+
     output("Server: %s %s (%s)\n", SHORTSWNAME,wims_version,LONGSWNAME);
     if(!robot_access && strcasecmp(usecookie,"yes")==0 && setcookie
        && mode!=mode_popup) {
@@ -1178,8 +1220,8 @@ void main_phtml_put(char *mname)
     if(vlink==NULL || *vlink==0) vlink="blue";
     refcolor=getvar("wims_ref_bgcolor");
     if(refcolor==NULL || *refcolor==0) {
-     setvar("wims_ref_bgcolor","white");
-     refcolor="white";
+      setvar("wims_ref_bgcolor","white");
+      refcolor="white";
     }
     bg=getvar("wims_bgimg"); bgbuf[0]=0;
     if(bg!=NULL && *bg!=0 && strchr(bg,'\"')==NULL) {
@@ -1206,8 +1248,7 @@ void main_phtml_put(char *mname)
      snprintf(dirnbuf,sizeof(dirnbuf),"dir=\"%s\"",dirn);
     }
     else dirnbuf[0]=0;
-    snprintf(buf,sizeof(buf),
-          "class=\"main_body\" %s",dirnbuf);
+    snprintf(buf,sizeof(buf), "class=\"main_body\" %s",dirnbuf);
     setvar("wims_htmlbody",buf);
     phtml_put(mname,0);
 }
